@@ -146,9 +146,9 @@ def crop_2D_image_force_fg(img, crop_size, valid_voxels):
                                        selected_center_voxel[i])
 
     result = img[:, (selected_center_voxel[0] - crop_size[0] // 2):(
-                selected_center_voxel[0] + crop_size[0] // 2 + crop_size[0] % 2),
+            selected_center_voxel[0] + crop_size[0] // 2 + crop_size[0] % 2),
              (selected_center_voxel[1] - crop_size[1] // 2):(
-                         selected_center_voxel[1] + crop_size[1] // 2 + crop_size[1] % 2)]
+                     selected_center_voxel[1] + crop_size[1] // 2 + crop_size[1] % 2)]
     return result
 
 
@@ -215,7 +215,7 @@ class DataLoader3D(SlimDataLoaderBase):
             case_all_data = np.load(self._data[k]['data_file'][:-4] + ".npy", self.memmap_mode)
         else:
             case_all_data = np.load(self._data[k]['data_file'])['data']
-        num_color_channels = case_all_data.shape[0] - num_seg
+        num_color_channels = case_all_data.shape[0] - 1
         data_shape = (self.batch_size, num_color_channels, *self.patch_size)
         seg_shape = (self.batch_size, num_seg, *self.patch_size)
         return data_shape, seg_shape
@@ -296,6 +296,10 @@ class DataLoader3D(SlimDataLoaderBase):
                 bbox_y_lb = np.random.randint(lb_y, ub_y + 1)
                 bbox_z_lb = np.random.randint(lb_z, ub_z + 1)
             else:
+                # these values should have been precomputed
+                if 'class_locations' not in properties.keys():
+                    raise RuntimeError("Please rerun the preprocessing with the newest version of nnU-Net!")
+
                 # this saves us a np.unique. Preprocessing already did that for all cases. Neat.
                 foreground_classes = np.array(
                     [i for i in properties['class_locations'].keys() if len(properties['class_locations'][i]) != 0])
@@ -309,9 +313,6 @@ class DataLoader3D(SlimDataLoaderBase):
                 else:
                     selected_class = np.random.choice(foreground_classes)
 
-                    # these values should have been precomputed
-                    if 'class_locations' not in properties.keys():
-                        raise RuntimeError("Please rerun the preprocessing with the newest version of nnU-Net!")
                     voxels_of_that_class = properties['class_locations'][selected_class]
 
                 if voxels_of_that_class is not None:
@@ -354,30 +355,26 @@ class DataLoader3D(SlimDataLoaderBase):
                                           valid_bbox_y_lb:valid_bbox_y_ub,
                                           valid_bbox_z_lb:valid_bbox_z_ub]
 
-            case_all_data_donly = np.pad(case_all_data[:-1], ((0, 0),
-                                                              (-min(0, bbox_x_lb), max(bbox_x_ub - shape[0], 0)),
-                                                              (-min(0, bbox_y_lb), max(bbox_y_ub - shape[1], 0)),
-                                                              (-min(0, bbox_z_lb), max(bbox_z_ub - shape[2], 0))),
-                                         self.pad_mode, **self.pad_kwargs_data)
+            data[j] = np.pad(case_all_data[:-1], ((0, 0),
+                                                  (-min(0, bbox_x_lb), max(bbox_x_ub - shape[0], 0)),
+                                                  (-min(0, bbox_y_lb), max(bbox_y_ub - shape[1], 0)),
+                                                  (-min(0, bbox_z_lb), max(bbox_z_ub - shape[2], 0))),
+                             self.pad_mode, **self.pad_kwargs_data)
 
-            case_all_data_segonly = np.pad(case_all_data[-1:], ((0, 0),
-                                                                (-min(0, bbox_x_lb), max(bbox_x_ub - shape[0], 0)),
-                                                                (-min(0, bbox_y_lb), max(bbox_y_ub - shape[1], 0)),
-                                                                (-min(0, bbox_z_lb), max(bbox_z_ub - shape[2], 0))),
-                                           'constant', **{'constant_values': -1})
+            seg[j, 0] = np.pad(case_all_data[-1:], ((0, 0),
+                                                    (-min(0, bbox_x_lb), max(bbox_x_ub - shape[0], 0)),
+                                                    (-min(0, bbox_y_lb), max(bbox_y_ub - shape[1], 0)),
+                                                    (-min(0, bbox_z_lb), max(bbox_z_ub - shape[2], 0))),
+                               'constant', **{'constant_values': -1})
             if seg_from_previous_stage is not None:
-                seg_from_previous_stage = np.pad(seg_from_previous_stage, ((0, 0),
-                                                                           (-min(0, bbox_x_lb),
-                                                                            max(bbox_x_ub - shape[0], 0)),
-                                                                           (-min(0, bbox_y_lb),
-                                                                            max(bbox_y_ub - shape[1], 0)),
-                                                                           (-min(0, bbox_z_lb),
-                                                                            max(bbox_z_ub - shape[2], 0))),
-                                                 'constant', **{'constant_values': 0})
-                case_all_data_segonly = np.concatenate((case_all_data_segonly, seg_from_previous_stage), 0)
-
-            data[j] = case_all_data_donly
-            seg[j] = case_all_data_segonly
+                seg[j, 1] = np.pad(seg_from_previous_stage, ((0, 0),
+                                                             (-min(0, bbox_x_lb),
+                                                              max(bbox_x_ub - shape[0], 0)),
+                                                             (-min(0, bbox_y_lb),
+                                                              max(bbox_y_ub - shape[1], 0)),
+                                                             (-min(0, bbox_z_lb),
+                                                              max(bbox_z_ub - shape[2], 0))),
+                                   'constant', **{'constant_values': 0})
 
         return {'data': data, 'seg': seg, 'properties': case_properties, 'keys': selected_keys}
 
@@ -479,6 +476,10 @@ class DataLoader2D(SlimDataLoaderBase):
                 random_slice = np.random.choice(case_all_data.shape[1])
                 selected_class = None
             else:
+                # these values should have been precomputed
+                if 'class_locations' not in properties.keys():
+                    raise RuntimeError("Please rerun the preprocessing with the newest version of nnU-Net!")
+
                 foreground_classes = np.array(
                     [i for i in properties['class_locations'].keys() if len(properties['class_locations'][i]) != 0])
                 foreground_classes = foreground_classes[foreground_classes > 0]
@@ -488,9 +489,6 @@ class DataLoader2D(SlimDataLoaderBase):
                     print('case does not contain any foreground classes', i)
                 else:
                     selected_class = np.random.choice(foreground_classes)
-                    # these values should have been precomputed
-                    if 'class_locations' not in properties.keys():
-                        raise RuntimeError("Please rerun the preprocessing with the newest version of nnU-Net!")
 
                     voxels_of_that_class = properties['class_locations'][selected_class]
                     valid_slices = np.unique(voxels_of_that_class[:, 0])
