@@ -94,8 +94,6 @@ class NetworkTrainer(object):
         # too high the training will take forever
         self.train_loss_MA_alpha = 0.93  # alpha * old + (1-alpha) * new
         self.train_loss_MA_eps = 5e-4  # new MA must be at least this much better (smaller)
-        self.save_every = 50
-        self.save_latest_only = True
         self.max_num_epochs = 1000
         self.num_batches_per_epoch = 250
         self.num_val_batches_per_epoch = 50
@@ -120,6 +118,14 @@ class NetworkTrainer(object):
         if 'nnunet_use_progress_bar' in os.environ.keys():
             self.use_progress_bar = bool(int(os.environ['nnunet_use_progress_bar']))
 
+        ################# Settings for saving checkpoints ##################################
+        self.save_every = 50
+        self.save_latest_only = True  # if false it will not store/overwrite _latest but separate files each
+        # time an intermediate checkpoint is created
+        self.save_intermediate_checkpoints = True  # whether or not to save checkpoint_latest
+        self.save_best_checkpoint = True  # whether or not to save the best checkpoint according to self.best_val_eval_criterion_MA
+        self.save_final_checkpoint = True  # whether or not to save the final checkpoint
+
     @abstractmethod
     def initialize(self, training=True):
         """
@@ -472,7 +478,7 @@ class NetworkTrainer(object):
 
         self.epoch -= 1  # if we don't do this we can get a problem with loading model_final_checkpoint.
 
-        self.save_checkpoint(join(self.output_folder, "model_final_checkpoint.model"))
+        if self.save_final_checkpoint: self.save_checkpoint(join(self.output_folder, "model_final_checkpoint.model"))
         # now we can delete latest as it will be identical with final
         if isfile(join(self.output_folder, "model_latest.model")):
             os.remove(join(self.output_folder, "model_latest.model"))
@@ -496,7 +502,7 @@ class NetworkTrainer(object):
         Saves a checkpoint every save_ever epochs.
         :return:
         """
-        if self.epoch % self.save_every == (self.save_every - 1):
+        if self.save_intermediate_checkpoints and (self.epoch % self.save_every == (self.save_every - 1)):
             self.print_to_log_file("saving scheduled checkpoint file...")
             if not self.save_latest_only:
                 self.save_checkpoint(join(self.output_folder, "model_ep_%03.0d.model" % (self.epoch + 1)))
@@ -552,7 +558,7 @@ class NetworkTrainer(object):
             if self.val_eval_criterion_MA > self.best_val_eval_criterion_MA:
                 self.best_val_eval_criterion_MA = self.val_eval_criterion_MA
                 #self.print_to_log_file("saving best epoch checkpoint...")
-                self.save_checkpoint(join(self.output_folder, "model_best.model"))
+                if self.save_best_checkpoint: self.save_checkpoint(join(self.output_folder, "model_best.model"))
 
             # Now see if the moving average of the train loss has improved. If yes then reset patience, else
             # increase patience
